pub struct UiApplicationPage {
pub id: String,
pub route: String,
pub title: String,
pub description: Option<String>,
pub template: UiPageTemplate,
pub eyebrow: Option<String>,
pub hero: Option<UiPageHero>,
pub regions: Vec<UiPageRegion>,
pub aside: Vec<Component>,
pub footer: Vec<Component>,
pub atmosphere: UiPageAtmosphere,
}Fields
id: Stringroute: Stringtitle: Stringdescription: Option<String>template: UiPageTemplateeyebrow: Option<String>hero: Option<UiPageHero>regions: Vec<UiPageRegion>aside: Vec<Component>atmosphere: UiPageAtmosphereTrait Implementations
Sourceimpl Clone for UiApplicationPage
impl Clone for UiApplicationPage
Sourcefn clone(&self) -> UiApplicationPage
fn clone(&self) -> UiApplicationPage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UiApplicationPage
impl Debug for UiApplicationPage
Sourceimpl<'de> Deserialize<'de> for UiApplicationPage
impl<'de> Deserialize<'de> for UiApplicationPage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UiApplicationPage
impl JsonSchema for UiApplicationPage
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for UiApplicationPage
impl RefUnwindSafe for UiApplicationPage
impl Send for UiApplicationPage
impl Sync for UiApplicationPage
impl Unpin for UiApplicationPage
impl UnsafeUnpin for UiApplicationPage
impl UnwindSafe for UiApplicationPage