pub struct UiPageRegion {
pub id: String,
pub title: Option<String>,
pub description: Option<String>,
pub layout: UiRegionLayout,
pub columns: u8,
pub tone: UiRegionTone,
pub components: Vec<Component>,
}Fields
id: Stringtitle: Option<String>description: Option<String>layout: UiRegionLayoutcolumns: u8tone: UiRegionTonecomponents: Vec<Component>Trait Implementations
Sourceimpl Clone for UiPageRegion
impl Clone for UiPageRegion
Sourcefn clone(&self) -> UiPageRegion
fn clone(&self) -> UiPageRegion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UiPageRegion
impl Debug for UiPageRegion
Sourceimpl<'de> Deserialize<'de> for UiPageRegion
impl<'de> Deserialize<'de> for UiPageRegion
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UiPageRegion
impl JsonSchema for UiPageRegion
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for UiPageRegion
impl RefUnwindSafe for UiPageRegion
impl Send for UiPageRegion
impl Sync for UiPageRegion
impl Unpin for UiPageRegion
impl UnsafeUnpin for UiPageRegion
impl UnwindSafe for UiPageRegion