pub struct KitAsset {
pub id: String,
pub kind: KitAssetKind,
pub uri: String,
pub mime_type: String,
pub alt: String,
pub sha256: Option<String>,
pub license: Option<String>,
pub width: Option<u32>,
pub height: Option<u32>,
pub byte_size: Option<u64>,
}Expand description
An approved, addressable brand asset. Components reference these as kit://<id>.
Fields
id: Stringkind: KitAssetKinduri: Stringmime_type: Stringalt: Stringsha256: Option<String>license: Option<String>width: Option<u32>height: Option<u32>byte_size: Option<u64>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for KitAsset
impl<'de> Deserialize<'de> for KitAsset
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for KitAsset
impl JsonSchema for KitAsset
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for KitAsset
impl RefUnwindSafe for KitAsset
impl Send for KitAsset
impl Sync for KitAsset
impl Unpin for KitAsset
impl UnsafeUnpin for KitAsset
impl UnwindSafe for KitAsset