pub struct KitColors {
pub primary: String,
pub accent: Option<String>,
pub surface: Option<String>,
pub background: Option<String>,
pub text: Option<String>,
}Fields
primary: Stringaccent: Option<String>surface: Option<String>background: Option<String>text: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for KitColors
impl<'de> Deserialize<'de> for KitColors
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for KitColors
impl JsonSchema for KitColors
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for KitColors
impl RefUnwindSafe for KitColors
impl Send for KitColors
impl Sync for KitColors
impl Unpin for KitColors
impl UnsafeUnpin for KitColors
impl UnwindSafe for KitColors