pub struct KitComponentButton {
pub variants: Vec<String>,
}Fields
variants: Vec<String>Trait Implementations
Sourceimpl Clone for KitComponentButton
impl Clone for KitComponentButton
Sourcefn clone(&self) -> KitComponentButton
fn clone(&self) -> KitComponentButton
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KitComponentButton
impl Debug for KitComponentButton
Sourceimpl<'de> Deserialize<'de> for KitComponentButton
impl<'de> Deserialize<'de> for KitComponentButton
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for KitComponentButton
impl JsonSchema for KitComponentButton
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for KitComponentButton
impl RefUnwindSafe for KitComponentButton
impl Send for KitComponentButton
impl Sync for KitComponentButton
impl Unpin for KitComponentButton
impl UnsafeUnpin for KitComponentButton
impl UnwindSafe for KitComponentButton