pub struct KitComponentRecipe {
pub component: String,
pub variant: Option<String>,
pub asset_id: Option<String>,
pub slots: BTreeMap<String, String>,
}Expand description
Maps an agent-facing component to a renderer recipe and optional branded asset.
Fields
component: Stringvariant: Option<String>asset_id: Option<String>slots: BTreeMap<String, String>Trait Implementations
Sourceimpl Clone for KitComponentRecipe
impl Clone for KitComponentRecipe
Sourcefn clone(&self) -> KitComponentRecipe
fn clone(&self) -> KitComponentRecipe
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KitComponentRecipe
impl Debug for KitComponentRecipe
Sourceimpl<'de> Deserialize<'de> for KitComponentRecipe
impl<'de> Deserialize<'de> for KitComponentRecipe
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for KitComponentRecipe
impl JsonSchema for KitComponentRecipe
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for KitComponentRecipe
impl RefUnwindSafe for KitComponentRecipe
impl Send for KitComponentRecipe
impl Sync for KitComponentRecipe
impl Unpin for KitComponentRecipe
impl UnsafeUnpin for KitComponentRecipe
impl UnwindSafe for KitComponentRecipe