pub struct KitComponentTable {
pub striped: Option<bool>,
}Fields
striped: Option<bool>Trait Implementations
Sourceimpl Clone for KitComponentTable
impl Clone for KitComponentTable
Sourcefn clone(&self) -> KitComponentTable
fn clone(&self) -> KitComponentTable
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KitComponentTable
impl Debug for KitComponentTable
Sourceimpl<'de> Deserialize<'de> for KitComponentTable
impl<'de> Deserialize<'de> for KitComponentTable
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for KitComponentTable
impl JsonSchema for KitComponentTable
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for KitComponentTable
impl RefUnwindSafe for KitComponentTable
impl Send for KitComponentTable
impl Sync for KitComponentTable
impl Unpin for KitComponentTable
impl UnsafeUnpin for KitComponentTable
impl UnwindSafe for KitComponentTable