pub struct KitComponents {
pub button: Option<KitComponentButton>,
pub card: Option<KitComponentCard>,
pub input: Option<KitComponentInput>,
pub table: Option<KitComponentTable>,
}Fields
card: Option<KitComponentCard>input: Option<KitComponentInput>table: Option<KitComponentTable>Trait Implementations
Sourceimpl Clone for KitComponents
impl Clone for KitComponents
Sourcefn clone(&self) -> KitComponents
fn clone(&self) -> KitComponents
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KitComponents
impl Debug for KitComponents
Sourceimpl Default for KitComponents
impl Default for KitComponents
Sourcefn default() -> KitComponents
fn default() -> KitComponents
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for KitComponents
impl<'de> Deserialize<'de> for KitComponents
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for KitComponents
impl JsonSchema for KitComponents
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for KitComponents
impl RefUnwindSafe for KitComponents
impl Send for KitComponents
impl Sync for KitComponents
impl Unpin for KitComponents
impl UnsafeUnpin for KitComponents
impl UnwindSafe for KitComponents