pub struct KitProvenance {
pub source: KitSource,
pub source_uri: Option<String>,
pub generated_by: Option<String>,
pub reviewed_by: Option<String>,
pub approved_at: Option<String>,
}Fields
source: KitSourcesource_uri: Option<String>generated_by: Option<String>reviewed_by: Option<String>approved_at: Option<String>Trait Implementations
Sourceimpl Clone for KitProvenance
impl Clone for KitProvenance
Sourcefn clone(&self) -> KitProvenance
fn clone(&self) -> KitProvenance
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KitProvenance
impl Debug for KitProvenance
Sourceimpl Default for KitProvenance
impl Default for KitProvenance
Sourcefn default() -> KitProvenance
fn default() -> KitProvenance
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for KitProvenance
impl<'de> Deserialize<'de> for KitProvenance
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for KitProvenance
impl JsonSchema for KitProvenance
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for KitProvenance
impl RefUnwindSafe for KitProvenance
impl Send for KitProvenance
impl Sync for KitProvenance
impl Unpin for KitProvenance
impl UnsafeUnpin for KitProvenance
impl UnwindSafe for KitProvenance