pub struct KitSemanticColors {Show 19 fields
pub primary: String,
pub primary_foreground: String,
pub secondary: String,
pub secondary_foreground: String,
pub background: String,
pub foreground: String,
pub surface: String,
pub surface_foreground: String,
pub muted: String,
pub muted_foreground: String,
pub border: String,
pub input: String,
pub ring: String,
pub destructive: String,
pub destructive_foreground: String,
pub success: String,
pub warning: String,
pub info: String,
pub chart: Vec<String>,
}Fields
primary: Stringprimary_foreground: Stringsecondary: Stringsecondary_foreground: Stringbackground: Stringforeground: Stringsurface: Stringsurface_foreground: Stringmuted: Stringmuted_foreground: Stringborder: Stringinput: Stringring: Stringdestructive: Stringdestructive_foreground: Stringsuccess: Stringwarning: Stringinfo: Stringchart: Vec<String>Trait Implementations
Sourceimpl Clone for KitSemanticColors
impl Clone for KitSemanticColors
Sourcefn clone(&self) -> KitSemanticColors
fn clone(&self) -> KitSemanticColors
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KitSemanticColors
impl Debug for KitSemanticColors
Sourceimpl<'de> Deserialize<'de> for KitSemanticColors
impl<'de> Deserialize<'de> for KitSemanticColors
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for KitSemanticColors
impl JsonSchema for KitSemanticColors
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for KitSemanticColors
impl RefUnwindSafe for KitSemanticColors
impl Send for KitSemanticColors
impl Sync for KitSemanticColors
impl Unpin for KitSemanticColors
impl UnsafeUnpin for KitSemanticColors
impl UnwindSafe for KitSemanticColors