pub struct KitSpec {
pub name: String,
pub version: String,
pub brand: KitBrand,
pub colors: KitColors,
pub typography: KitTypography,
pub density: KitDensity,
pub radius: KitRadius,
pub components: KitComponents,
pub templates: Vec<String>,
}Fields
name: Stringversion: Stringbrand: KitBrandcolors: KitColorstypography: KitTypographydensity: KitDensityradius: KitRadiuscomponents: KitComponentstemplates: Vec<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for KitSpec
impl<'de> Deserialize<'de> for KitSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for KitSpec
impl JsonSchema for KitSpec
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for KitSpec
impl RefUnwindSafe for KitSpec
impl Send for KitSpec
impl Sync for KitSpec
impl Unpin for KitSpec
impl UnsafeUnpin for KitSpec
impl UnwindSafe for KitSpec