pub struct KitTemplate {
pub id: String,
pub description: Option<String>,
pub required_components: Vec<String>,
}Fields
id: Stringdescription: Option<String>required_components: Vec<String>Trait Implementations
Sourceimpl Clone for KitTemplate
impl Clone for KitTemplate
Sourcefn clone(&self) -> KitTemplate
fn clone(&self) -> KitTemplate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KitTemplate
impl Debug for KitTemplate
Sourceimpl<'de> Deserialize<'de> for KitTemplate
impl<'de> Deserialize<'de> for KitTemplate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for KitTemplate
impl JsonSchema for KitTemplate
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for KitTemplate
impl RefUnwindSafe for KitTemplate
impl Send for KitTemplate
impl Sync for KitTemplate
impl Unpin for KitTemplate
impl UnsafeUnpin for KitTemplate
impl UnwindSafe for KitTemplate