pub struct KitTypography {
pub family: String,
pub scale: Option<String>,
}Fields
family: Stringscale: Option<String>Trait Implementations
Sourceimpl Clone for KitTypography
impl Clone for KitTypography
Sourcefn clone(&self) -> KitTypography
fn clone(&self) -> KitTypography
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KitTypography
impl Debug for KitTypography
Sourceimpl<'de> Deserialize<'de> for KitTypography
impl<'de> Deserialize<'de> for KitTypography
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for KitTypography
impl JsonSchema for KitTypography
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for KitTypography
impl RefUnwindSafe for KitTypography
impl Send for KitTypography
impl Sync for KitTypography
impl Unpin for KitTypography
impl UnsafeUnpin for KitTypography
impl UnwindSafe for KitTypography