pub struct UiNotification {
pub severity: UiNotificationSeverity,
pub title: String,
pub body: String,
pub surface_ref: Option<SurfaceRef>,
pub action_id: Option<String>,
}Fields
severity: UiNotificationSeveritytitle: Stringbody: Stringsurface_ref: Option<SurfaceRef>action_id: Option<String>Trait Implementations
Sourceimpl Clone for UiNotification
impl Clone for UiNotification
Sourcefn clone(&self) -> UiNotification
fn clone(&self) -> UiNotification
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UiNotification
impl Debug for UiNotification
Sourceimpl<'de> Deserialize<'de> for UiNotification
impl<'de> Deserialize<'de> for UiNotification
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for UiNotification
Sourceimpl JsonSchema for UiNotification
impl JsonSchema for UiNotification
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for UiNotification
impl PartialEq for UiNotification
Sourceimpl Serialize for UiNotification
impl Serialize for UiNotification
impl StructuralPartialEq for UiNotification