pub struct Scene3d {
pub id: Option<String>,
pub title: Option<String>,
pub description: Option<String>,
pub height: u16,
pub background: SceneBackground,
pub camera: SceneCamera,
pub objects: Vec<SceneObject>,
pub auto_rotate: bool,
pub controls: bool,
pub fallback: Option<String>,
}Expand description
Declarative, bounded 3D scene. Hosts retain control of loading, rendering, interaction, and asset policy; agents cannot inject shaders or executable code.
Fields
id: Option<String>title: Option<String>description: Option<String>height: u16background: SceneBackgroundcamera: SceneCameraobjects: Vec<SceneObject>auto_rotate: boolcontrols: boolfallback: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Scene3d
impl<'de> Deserialize<'de> for Scene3d
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Scene3d
impl JsonSchema for Scene3d
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Scene3d
impl RefUnwindSafe for Scene3d
impl Send for Scene3d
impl Sync for Scene3d
impl Unpin for Scene3d
impl UnsafeUnpin for Scene3d
impl UnwindSafe for Scene3d