pub struct SceneModel {
pub id: String,
pub asset_id: String,
pub position: [f32; 3],
pub rotation: [f32; 3],
pub scale: [f32; 3],
pub label: Option<String>,
pub action_id: Option<String>,
}Fields
id: Stringasset_id: StringApproved model_3d asset from the active brand kit.
position: [f32; 3]rotation: [f32; 3]scale: [f32; 3]label: Option<String>action_id: Option<String>Trait Implementations
Sourceimpl Clone for SceneModel
impl Clone for SceneModel
Sourcefn clone(&self) -> SceneModel
fn clone(&self) -> SceneModel
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SceneModel
impl Debug for SceneModel
Sourceimpl<'de> Deserialize<'de> for SceneModel
impl<'de> Deserialize<'de> for SceneModel
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SceneModel
impl JsonSchema for SceneModel
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SceneModel
impl RefUnwindSafe for SceneModel
impl Send for SceneModel
impl Sync for SceneModel
impl Unpin for SceneModel
impl UnsafeUnpin for SceneModel
impl UnwindSafe for SceneModel