pub struct ScenePrimitive {
pub id: String,
pub shape: ScenePrimitiveShape,
pub position: [f32; 3],
pub rotation: [f32; 3],
pub scale: [f32; 3],
pub material: SceneMaterialRole,
pub label: Option<String>,
pub action_id: Option<String>,
}Fields
id: Stringshape: ScenePrimitiveShapeposition: [f32; 3]rotation: [f32; 3]scale: [f32; 3]material: SceneMaterialRolelabel: Option<String>action_id: Option<String>Trait Implementations
Sourceimpl Clone for ScenePrimitive
impl Clone for ScenePrimitive
Sourcefn clone(&self) -> ScenePrimitive
fn clone(&self) -> ScenePrimitive
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScenePrimitive
impl Debug for ScenePrimitive
Sourceimpl<'de> Deserialize<'de> for ScenePrimitive
impl<'de> Deserialize<'de> for ScenePrimitive
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScenePrimitive
impl JsonSchema for ScenePrimitive
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ScenePrimitive
impl RefUnwindSafe for ScenePrimitive
impl Send for ScenePrimitive
impl Sync for ScenePrimitive
impl Unpin for ScenePrimitive
impl UnsafeUnpin for ScenePrimitive
impl UnwindSafe for ScenePrimitive